@@ -1,5 +1,5 @@
-VERSION = (1,0,9)
-__version__ = "1.0.9"
+VERSION = (1,0,10)
+__version__ = "1.0.10"
 import random
 import os
 
@@ -60,6 +60,6 @@ try:
 
     init_themes()
     set_themes()
-except Exception as ex:
+except Exception, ex:
     print 'An error occured setting up the themes: %s' % ex
 
